"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseAtRules = exports.parseRules = void 0;
const postcss_1 = __importDefault(require("postcss"));
function parseRules(cssString, options = { parseAtRules: true }) {
    const cssObject = {};
    if (options.rulesGroupName) {
        cssObject[options.rulesGroupName] = {};
    }
    postcss_1.default.parse(cssString).walkRules((rule) => {
        const selector = rule.selector;
        const styles = {};
        const ignoredSelectors = ['from', 'to'];
        if (!ignoredSelectors.includes(selector) && rule.parent?.type !== 'atrule') {
            rule.walkDecls((decl) => {
                styles[decl.prop] = decl.value;
            });
            if (options.rulesGroupName) {
                const groupedStylesRecord = cssObject[options.rulesGroupName];
                groupedStylesRecord[selector] = { styles };
            }
            else {
                cssObject[selector] = { styles };
            }
        }
    });
    return cssObject;
}
exports.parseRules = parseRules;
function parseAtRules(cssString, options = { parseAtRules: true }) {
    const cssObject = {};
    if (options.atRulesGroupName) {
        cssObject[options.atRulesGroupName] = {};
    }
    postcss_1.default.parse(cssString).walkAtRules((atRule) => {
        const atRuleSelector = ('@').concat(atRule.name.concat(' ', atRule.params));
        const styles = {};
        if (atRule.nodes) {
            atRule.walkRules((rule) => {
                const selector = rule.selector;
                const styles = {};
                rule.walkDecls((decl) => {
                    styles[decl.prop] = decl.value;
                });
                if (options.atRulesGroupName && !atRuleSelectorExist(cssObject, options.atRulesGroupName, atRuleSelector)) {
                    const groupedStylesRecord = cssObject[options.atRulesGroupName];
                    groupedStylesRecord[atRuleSelector] = {};
                }
                if (options.atRulesGroupName) {
                    const group = cssObject[options.atRulesGroupName];
                    const groupStylesRecord = group[atRuleSelector];
                    groupStylesRecord[selector] = { styles };
                }
                else {
                    cssObject[selector] = { styles };
                }
            });
        }
        else {
            atRule.walkDecls((decl) => {
                styles[decl.prop] = decl.value;
            });
            if (options.atRulesGroupName) {
                const groupedStylesRecord = cssObject[options.atRulesGroupName];
                groupedStylesRecord[atRuleSelector] = atRuleSelector;
            }
            else {
                cssObject[atRuleSelector] = atRuleSelector;
            }
        }
    });
    return cssObject;
}
exports.parseAtRules = parseAtRules;
function atRuleSelectorExist(cssObject, groupName, selector) {
    const atRulesGroupRecord = cssObject[groupName];
    return !!atRulesGroupRecord[selector];
}
//# sourceMappingURL=parsers.js.map